<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.cpp" line="105"/>
        <source>Initialization error</source>
        <translation>Erreur lors de l&apos;initialisation</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="106"/>
        <source>Could not find syntax definitions. Check installation.</source>
        <translation>Impossible de trouver les définitions des syntaxes. Vérifiez votre installation.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="182"/>
        <source>Always at your service</source>
        <translation>Toujours à votre service</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="209"/>
        <source>Select one or more files to open</source>
        <translation>Sélectionnez un ou plusieurs fichiers à ouvrir</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="246"/>
        <source>Select destination directory</source>
        <translation>Sélectionnez un répertoire de destination</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="878"/>
        <location filename="mainwindow.cpp" line="909"/>
        <source>Output error</source>
        <translation>Erreur de sortie</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="878"/>
        <source>Output directory does not exist!</source>
        <translation>Le répertoire de destination n&apos;existe pas !</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="909"/>
        <source>You must define a style output file!</source>
        <translation>Vous devez définir un fichier de style de sortie !</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="941"/>
        <source>Processing %1 (%2/%3)</source>
        <translation>Traitement de %1 (%2/%3)</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="947"/>
        <source>Language definition error</source>
        <translation>Erreur de définition du langage</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="948"/>
        <source>Invalid regular expression in %1:
%2</source>
        <translation>Expression régulière non valide dans %1 :
%2</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="952"/>
        <source>Unknown syntax</source>
        <translation>Syntaxe inconnue</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="952"/>
        <source>Could not convert %1</source>
        <translation>Impossible de convertir %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="955"/>
        <source>Lua error</source>
        <translation>Erreur Lua</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="955"/>
        <source>Could not convert %1:
Lua Syntax error: %2</source>
        <translation>Impossible de convertir %1 :
Erreur de syntaxe Lua : %2</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1028"/>
        <source>Converted %1 files in %2 ms</source>
        <translation>%1 fichier(s) converti(s) en %2 ms</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1126"/>
        <source>Conversion of &quot;%1&quot; not possible.</source>
        <translation>Conversion de &quot;%1&quot; impossible.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1126"/>
        <location filename="mainwindow.cpp" line="1244"/>
        <location filename="mainwindow.cpp" line="1269"/>
        <source>clipboard data</source>
        <translation>données du presse-papiers</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1193"/>
        <source>%1 options</source>
        <translation>Options de %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1230"/>
        <location filename="mainwindow.cpp" line="1236"/>
        <source>(user script)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1243"/>
        <source>Preview (%1):</source>
        <translation>Aperçu (%1) :</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1246"/>
        <source>Current syntax: %1 %2</source>
        <translation>Syntaxe actuelle : %1 %2</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1247"/>
        <source>Current theme: %1 %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Current syntax: %1</source>
        <translation type="vanished">Syntaxe actuelle : %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1269"/>
        <source>Preview of &quot;%1&quot; not possible.</source>
        <translation>Impossible de donner un aperçu de &quot;%1&quot;.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1306"/>
        <location filename="mainwindow.cpp" line="1310"/>
        <location filename="mainwindow.cpp" line="1314"/>
        <location filename="mainwindow.cpp" line="1319"/>
        <source>Choose a style include file</source>
        <translation>Choisissez un fichier de style à inclure</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1324"/>
        <source>About providing translations</source>
        <translation>À propos des traductions</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1325"/>
        <source>The GUI was developed using the Qt toolkit, and translations may be provided using the tools Qt Linguist and lrelease.
The highlight.ts file for Linguist resides in the src/gui-qt subdirectory.
The qm file generated by lrelease has to be saved in gui-files/l10n.

Please send a note to as (at) andre-simon (dot) de if you have issues during translating or if you have finished or updated a translation.</source>
        <translation>Cette interface graphique a été développée en utilisant Qt. Les traductions peuvent être fournies en utilisant les outils Qt Linguist et lrelease.
Le fichier highlight.ts pour Linguist est situé dans le sous-dossier src/gui-qt.
Le fichier .qm généré par lrelease doit être sauvegardé dans gui-files/l10n.

Veuillez m&apos;envoyer une note à l&apos;adresse « as (at) andre-simon (dot) de » si vous rencontrez des problèmes durant la traduction ou si vous avez terminé ou mis à jour une traduction.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1383"/>
        <source>Select one or more plug-ins</source>
        <translation>Sélectionner un ou plusieurs greffons</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1394"/>
        <source>Select one or more syntax or theme scripts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1454"/>
        <source>Choose a plug-in input file</source>
        <translation>Choisissez un fichier d&apos;entrée pour le greffon</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1520"/>
        <source>Some plug-in effects may not be visible in the preview.</source>
        <translation>Certains effets du greffon peuvent ne pas être visibles dans l&apos;aperçu.</translation>
    </message>
</context>
<context>
    <name>MainWindowClass</name>
    <message>
        <location filename="mainwindow.ui" line="17"/>
        <source>Highlight</source>
        <translation>Highlight</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="30"/>
        <source>Preview</source>
        <translation>Aperçu</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="58"/>
        <source>Output progress:</source>
        <translation>Progression :</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="86"/>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="94"/>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="109"/>
        <source>Wi&amp;ndows</source>
        <translation>Fe&amp;nêtres</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="129"/>
        <source>H&amp;ighlighting options</source>
        <oldsource>Highlighting options</oldsource>
        <translation>Options de coloration</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="174"/>
        <source>Files</source>
        <translation>Fichiers</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="180"/>
        <source>Choose the source code files you want to convert.</source>
        <translation>Choisir les fichiers de code source que vous voulez convertir.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="186"/>
        <source>Choose input files</source>
        <translation>Choisir les fichiers d&apos;entrée</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="212"/>
        <source>List of input files.</source>
        <translation>Liste des fichiers en entrée.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="236"/>
        <source>Remove the selected input files.</source>
        <translation>Supprimer les fichiers sources sélectionnés.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="239"/>
        <location filename="mainwindow.ui" line="553"/>
        <location filename="mainwindow.ui" line="689"/>
        <source>Clear selection</source>
        <translation>Effacer la sélection</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="246"/>
        <source>Remove all input files.</source>
        <translation>Supprimer tous les fichiers d&apos;entrée.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="249"/>
        <location filename="mainwindow.ui" line="563"/>
        <location filename="mainwindow.ui" line="699"/>
        <source>Clear all</source>
        <translation>Tout effacer</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="273"/>
        <source>Output destination:</source>
        <translation>Destination de la sortie :</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="288"/>
        <source>Output directory</source>
        <translation>Répertoire de destination</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="307"/>
        <source>Select the output directory.</source>
        <translation>Sélectionner le répertoire de destination.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="310"/>
        <location filename="mainwindow.ui" line="640"/>
        <location filename="mainwindow.ui" line="1286"/>
        <location filename="mainwindow.ui" line="1555"/>
        <location filename="mainwindow.ui" line="1663"/>
        <location filename="mainwindow.ui" line="1958"/>
        <source>...</source>
        <translation>…</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="329"/>
        <source>Browse output directory</source>
        <translation>Parcourir le répertoire de destination</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="345"/>
        <source>Save output in the input file directories.</source>
        <translation>Sauvegarder la sortie dans les répertoires des fichiers d&apos;entrée.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="348"/>
        <source>Write to source directories</source>
        <translation>Écrire dans les répertoires sources</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="383"/>
        <source>Start the conversion of your input files.</source>
        <translation>Démarrer la conversion de vos fichiers en entrée.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="386"/>
        <source>Convert files</source>
        <translation>Convertir les fichiers</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="396"/>
        <source>Copy highlighted code of the seleted file into the clipboard.</source>
        <translation>Copier le code coloré du fichier sélectionné dans le presse-papiers.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="399"/>
        <source>Copy file to clipboard</source>
        <translation>Copier le fichier dans le presse-papiers</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="411"/>
        <source>Clipboard</source>
        <translation>Presse-papiers</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="419"/>
        <source>Select syntax:</source>
        <translation>Sélectionner une syntaxe :</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="426"/>
        <source>Select the correct syntax of the code snippet.</source>
        <translation>Sélectionner la syntaxe correcte de l&apos;extrait de code.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="435"/>
        <source>Paste clipboard content into the preview window.</source>
        <translation>Coller le contenu du presse-papiers dans la fenêtre de prévisualisation.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="438"/>
        <source>Paste from clipboard (%1)</source>
        <translation>Coller depuis le presse-papiers (%1)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="455"/>
        <source>Copy highlighted code into the clipboard.</source>
        <translation>Copier le code coloriée dans le presse-papiers.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="458"/>
        <source>Copy preview to clipboard (%1)</source>
        <translation>Copier l&apos;aperçu vers le presse-papiers (%1)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="481"/>
        <source>Paste code from clipboard and copy the output back in one step</source>
        <translation>Coller le code depuis le presse-papiers et recopier la sortie en une seule étape</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="487"/>
        <source>Paste, Convert and Copy</source>
        <translation>Coller, convertir et copier</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="512"/>
        <source>Plug-ins</source>
        <translation>Greffons</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="518"/>
        <source>Choose a plug-in script.</source>
        <translation>Choisir un script de greffon.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="521"/>
        <source>Add plug-in to pool</source>
        <translation>Ajouter un greffon à la sélection</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="532"/>
        <source>List of plug-ins. Toggle checkbox to enable the scripts. The preview window may not display all plug-in effects.</source>
        <translation>Liste des greffons. Cochez pour activer les scripts. La fenêtre de prévisualisation peut ne pas afficher les effets de tous les greffons.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="550"/>
        <source>Remove the selected plug-ins.</source>
        <translation>Supprimer les greffons sélectionnés.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="560"/>
        <source>Remove all plug-ins.</source>
        <translation>Supprimer tous les greffons.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="572"/>
        <location filename="mainwindow.ui" line="708"/>
        <source>Description</source>
        <translation>Description</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="584"/>
        <source>Shows decription of a selected plug-in script.</source>
        <translation>Affiche la description d&apos;un script de greffon sélectionné.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="587"/>
        <source>Plug-In description</source>
        <translation>Description du greffon</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="615"/>
        <source>Plug-in parameter</source>
        <translation>Paramètres du greffon</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="624"/>
        <source>Optional plug-in parameter, this may be a path to a plug-in input file</source>
        <translation>Paramètres optionnels du greffon, cela peut être un chemin vers un fichier d&apos;entrée</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="637"/>
        <source>Select the plug-in input file.</source>
        <translation>Sélectionner le fichier d&apos;entrée du greffon.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="654"/>
        <source>Scripts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="660"/>
        <source>Choose a custom syntax or theme script.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="663"/>
        <source>Add custom script to pool</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="677"/>
        <source>You can check one file of each type (syntax and theme) to override the default behaviour. If checked, the scripts will be watched for changes.</source>
        <oldsource>You can check one file of each type (syntax and theme) to override the default behaviour.</oldsource>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="686"/>
        <source>Remove the selected scripts.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="696"/>
        <source>Remove all scripts.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="714"/>
        <source>Shows decription of a selected script.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="717"/>
        <source>Script description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="756"/>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="776"/>
        <source>Output for&amp;mat:</source>
        <translation>For&amp;mat de sortie :</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="798"/>
        <source>Choose an output format.</source>
        <translation>Choisir un format de sortie.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="802"/>
        <source>HTML</source>
        <translation>HTML</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="807"/>
        <source>XHTML</source>
        <translation>XHTML</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="812"/>
        <source>LaTeX</source>
        <translation>LaTeX</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="817"/>
        <source>TeX</source>
        <translation>TeX</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="822"/>
        <source>RTF</source>
        <translation>RTF</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="827"/>
        <source>ODT</source>
        <translation>ODT</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="832"/>
        <source>SVG</source>
        <translation>SVG</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="837"/>
        <source>BBCode</source>
        <translation>BBCode</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="856"/>
        <source>Add line numbers to the output.</source>
        <translation>Ajouter les numéros de ligne à la sortie.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="859"/>
        <source>Add line numbers</source>
        <translation>Ajouter les numéros de lignes</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="879"/>
        <source>Set line numbering start.</source>
        <translation>Définir le début de la numérotation.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="898"/>
        <source>Select the line number width.</source>
        <translation>Sélectionner la largeur des numéros de lignes.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="919"/>
        <source>Fill leading space of line numbers with zeroes.</source>
        <translation>Remplir l&apos;espace avant les numéros de lignes par des zéros.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="922"/>
        <source>Pad with zeroes</source>
        <translation>Compléter avec des zéros</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="935"/>
        <source>Generate output without document header and footer.</source>
        <translation>Générer la sortie sans haut ni bas de page.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="938"/>
        <source>Omit header and footer</source>
        <translation>Omettre haut et bas de page</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="945"/>
        <source>Output any plug-in text injections even if document header and footer is omitted.</source>
        <translation>Conserver toutes les injections de texte des greffons, même si le haut et le bas de page sont omis.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="948"/>
        <source>Keep Plug-In injections</source>
        <translation>Garder les injections des greffons</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="955"/>
        <source>Test if input data is not binary.
Removes Unicode BOM mark.</source>
        <translation>Vérifier si les données en entrée ne sont pas binaires.
Supprime les marques Unicode BOM.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="959"/>
        <source>Validate input data</source>
        <translation>Valider les données en entrée</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="966"/>
        <source>Generate output without version information comment.</source>
        <translation>Générer la sortie sans commentaire d&apos;information sur la version.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="969"/>
        <source>Omit version info comment</source>
        <translation>Omettre les informations de version</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="978"/>
        <source>Set the output file encoding.</source>
        <translation>Définir l&apos;encodage du fichier de sortie.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="981"/>
        <source>Set encoding:</source>
        <translation>Définir l&apos;encodage :</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="988"/>
        <source>Select or define the encoding.
The result has to match the input file encoding.</source>
        <translation>Sélectionner ou définir l&apos;encodage.
Le résultat doit correspondre à l&apos;encodage du fichier d&apos;entrée.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="999"/>
        <source>ISO-8859-1</source>
        <translation>ISO-8859-1</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1004"/>
        <source>ISO-8859-2</source>
        <translation>ISO-8859-2</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1009"/>
        <source>ISO-8859-3</source>
        <translation>ISO-8859-3</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1014"/>
        <source>ISO-8859-4</source>
        <translation>ISO-8859-4</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1019"/>
        <source>ISO-8859-5</source>
        <translation>ISO-8859-5</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1024"/>
        <source>ISO-8859-6</source>
        <translation>ISO-8859-6</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1029"/>
        <source>ISO-8859-7</source>
        <translation>ISO-8859-7</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1034"/>
        <source>ISO-8859-8</source>
        <translation>ISO-8859-8</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1039"/>
        <source>ISO-8859-9</source>
        <translation>ISO-8859-9</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1044"/>
        <source>ISO-8859-10</source>
        <translation>ISO-8859-10</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1049"/>
        <source>ISO-8859-11</source>
        <translation>ISO-8859-11</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1054"/>
        <source>ISO-8859-12</source>
        <translation>ISO-8859-12</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1059"/>
        <source>ISO-8859-13</source>
        <translation>ISO-8859-13</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1064"/>
        <source>ISO-8859-14</source>
        <translation>ISO-8859-14</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1069"/>
        <source>ISO-8859-15</source>
        <translation>ISO-8859-15</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1074"/>
        <source>UTF-8</source>
        <translation>UTF-8</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1098"/>
        <source>Output specific</source>
        <translation>Sortie spécifique</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1139"/>
        <source>Stylesheets</source>
        <translation>Feuilles de style</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1147"/>
        <location filename="mainwindow.ui" line="1473"/>
        <location filename="mainwindow.ui" line="1581"/>
        <location filename="mainwindow.ui" line="1876"/>
        <source>Include the style information in each output file.</source>
        <translation>Inclure les informations de style dans chaque fichier en sortie.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1150"/>
        <location filename="mainwindow.ui" line="1879"/>
        <source>Embed style (CSS)</source>
        <translation>Embarquer le style (CSS)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1163"/>
        <source>Add CSS information to each tag (do not use CSS class definitions).</source>
        <translation>Ajouter les informations CSS à chaque étiquette (ne pas utiliser les définitions de classes CSS).</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1166"/>
        <source>Inline CSS</source>
        <translation>CSS en ligne</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1180"/>
        <source>CSS class prefix:</source>
        <translation>Préfixe de classe CSS :</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1193"/>
        <source>Add a CSS class name prefix to avoid namespace clashes.</source>
        <translation>Ajouter un préfixe de nom de classe CSS pour éviter les conflits d&apos;espaces de noms.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1207"/>
        <location filename="mainwindow.ui" line="1485"/>
        <location filename="mainwindow.ui" line="1593"/>
        <location filename="mainwindow.ui" line="1888"/>
        <source>Stylesheet file:</source>
        <translation>Feuille de style :</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1226"/>
        <location filename="mainwindow.ui" line="1609"/>
        <location filename="mainwindow.ui" line="1904"/>
        <source>Name of the referenced style file.</source>
        <translation>Nom de la feuille de style référencée.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1229"/>
        <location filename="mainwindow.ui" line="1907"/>
        <source>highlight.css</source>
        <translation>highlight.css</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1240"/>
        <location filename="mainwindow.ui" line="1515"/>
        <location filename="mainwindow.ui" line="1623"/>
        <location filename="mainwindow.ui" line="1918"/>
        <source>Stylesheet include file:</source>
        <translation>Feuille de style à inclure :</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1270"/>
        <location filename="mainwindow.ui" line="1942"/>
        <source>Path of the CSS include file.</source>
        <translation>Chemin du fichier CSS à inclure.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1283"/>
        <source>Select a CSS include file.</source>
        <translation>Sélectionner un fichier CSS à inclure.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1312"/>
        <source>Misc</source>
        <translation>Divers</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1324"/>
        <source>Line numbering options:</source>
        <translation>Options de numérotation des lignes :</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1331"/>
        <source>Add an achor to each line.</source>
        <translation>Ajouter une ancre à chaque ligne.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1334"/>
        <source>Add line anchors</source>
        <translation>Ajouter des ancres aux lignes</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1341"/>
        <source>Add the filename as prefix to the anchors.</source>
        <translation>Ajouter le nom du fichier comme préfixe aux ancres.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1344"/>
        <source>Include file name in anchor</source>
        <translation>Inclure le nom du fichier dans l&apos;ancre</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1351"/>
        <source>Output the lines within an ordered list.</source>
        <translation>Afficher les lignes dans une liste ordonnée.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1354"/>
        <source>Output as ordered list</source>
        <translation>Traiter comme une liste ordonnée</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1368"/>
        <source>Generate an index file with hyperlinks to all outputted files.</source>
        <translation>Générer un fichier d&apos;index avec des hyperliens vers tous les fichiers de sortie.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1371"/>
        <source>Generate index file</source>
        <translation>Générer un fichier d&apos;index</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1378"/>
        <source>Add &amp;lt;pre&amp;gt; tags to the output, if the flag &quot;No document header and footer&quot; is selected.</source>
        <translation>Ajouter des balises &amp;lt;pre&amp;gt; à la sortie, si le haut et le bas de pages sont omis.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1381"/>
        <source>Enclose in pre tags</source>
        <translation>Entourer de balises pre</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1395"/>
        <source>Add HTML MIME Type when copying code to the clipboard</source>
        <translation>Ajouter le type MIME HTML lors de la copie du code dans le presse-papiers</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1398"/>
        <source>Copy with MIME type</source>
        <translation>Copier avec le type MIME</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1426"/>
        <source>Replace quotes by dq sequences.</source>
        <translation>Remplacer les guillements par des séquences dq.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1429"/>
        <source>Escape quotes</source>
        <translation>Échapper les guillements</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1436"/>
        <source>Adapt output for the Babel package</source>
        <translation>Adapter la sortie au paquet Babel</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1439"/>
        <source>Add Babel compatibility</source>
        <translation>Ajouter la compatibilité Babel</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1446"/>
        <source>Adapt output for the Beamer package</source>
        <translation>Adapter la sortie au paquet Beamer</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1449"/>
        <source>Add Beamer compatibility</source>
        <translation>Ajouter la compatibilité Beamer</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1456"/>
        <source>Replace default symbols (brackets, tilde) by nice redefinitions.</source>
        <translation>Remplacer les symboles par défaut (accolades, tilde) par de belles redéfinitions.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1459"/>
        <source>Add pretty symbols</source>
        <translation>Ajouter de jolis symboles</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1476"/>
        <source>Embed style (defs)</source>
        <translation>Embarquer le style (defs)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1501"/>
        <source>Name of the referenced  style file.</source>
        <translation>Nom de la feuille de style référencée.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1504"/>
        <location filename="mainwindow.ui" line="1612"/>
        <source>highlight.sty</source>
        <translation>highlight.sty</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1539"/>
        <location filename="mainwindow.ui" line="1647"/>
        <source>Path of the style include file.</source>
        <translation>Chemin du fichier de style à inclure.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1552"/>
        <location filename="mainwindow.ui" line="1660"/>
        <location filename="mainwindow.ui" line="1955"/>
        <source>Select a style include file.</source>
        <translation>Sélectionner un fichier de style à inclure.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1584"/>
        <source>Embed style (macros)</source>
        <translation>Embarquer le style (macros)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1689"/>
        <source>Add character stylesheets with formatting information.
You can select the stylesheets in your word processor to reformat additional text.</source>
        <translation>Ajouter des feuilles de style pour les caractères, avec des informations de formatage.
Vous pouvez sélectionner les feuilles de style dans votre logiciel de traitement de texte pour reformater du texte additionnel.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1693"/>
        <source>Add character styles</source>
        <translation>Ajouter des styles de caractère</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1700"/>
        <source>Set page color attribute to background color.</source>
        <translation>Définir l&apos;attribut de couleur de la page avec la couleur de fond.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1703"/>
        <source>Set page color</source>
        <translation>Définir la couleur de la page</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1712"/>
        <source>Page size:</source>
        <translation>Taille de la page :</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1725"/>
        <source>Select a page size.</source>
        <translation>Sélectionner une taille de page.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1732"/>
        <source>A3</source>
        <translation>A3</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1737"/>
        <source>A4</source>
        <translation>A4</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1742"/>
        <source>A5</source>
        <translation>A5</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1747"/>
        <source>B4</source>
        <translation>B4</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1752"/>
        <source>B5</source>
        <translation>B5</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1757"/>
        <source>B6</source>
        <translation>B6</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1762"/>
        <source>Letter</source>
        <translation>Lettre</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1767"/>
        <source>Legal</source>
        <translation>Légal</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1796"/>
        <source>I&amp;mage width:</source>
        <translation>Largeur de l&apos;i&amp;mage :</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1824"/>
        <source>Enter the SVG width (may contain units).</source>
        <translation>Saisir la largeur du SVG (peut contenir des unités).</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1844"/>
        <source>Height:</source>
        <translation>Hauteur :</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1860"/>
        <source>Enter the SVG height (may contain units).</source>
        <translation>Saisir la taille du SVG (peut contenir des unités).</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1984"/>
        <source>No options defined.</source>
        <translation>Aucune option définie.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2009"/>
        <source>Formatting</source>
        <translation>Formatage</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2032"/>
        <source>Color theme:</source>
        <translation>Thème de couleurs :</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2064"/>
        <source>Toggle classic theme or Base16 theme selection.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2067"/>
        <source>Base16</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2086"/>
        <source>Select a colour theme.</source>
        <translation>Sélectionner un thème de couleurs.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2103"/>
        <source>Reformat and indent your code.
This feature is enabled for C, C++, C# and Java code.</source>
        <translation>Reformater et indenter votre code.
Cette fonctionnalité est activée pour le code C, C++, C# et Java.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2107"/>
        <source>Reformat:</source>
        <translation>Reformatage :</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2126"/>
        <source>Choose a formatting scheme.</source>
        <translation>Choisir un schéma de formatage.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2140"/>
        <source>Change the keyword case.</source>
        <translation>Changer la casse.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2143"/>
        <source>Keyword case:</source>
        <translation>Casse des mots-clés :</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2162"/>
        <source>Select a keyword case.</source>
        <translation>Sélectionner une casse pour les mots-clés.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2169"/>
        <source>UPPER</source>
        <translation>MAJUSCULE</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2174"/>
        <source>lower</source>
        <translation>minuscule</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2179"/>
        <source>Capitalize</source>
        <translation>Casse de phrase</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2197"/>
        <source>Tab width:</source>
        <translation>Largeur des tabulations :</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2213"/>
        <source>Enter the number of spaces which replace a tab.
Set the width to 0 to keep tabs.</source>
        <translation>Saisir le nombre d&apos;espaces qui remplacent une tabulation.
Définir la largeur à 0 pour conserver les tabulations.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2228"/>
        <source>Enable line wrapping.</source>
        <translation>Activer le retour à la ligne automatique.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2231"/>
        <source>Line wrapping</source>
        <translation>Retour à la ligne</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2244"/>
        <source>Enter the maximum line length.</source>
        <translation>Saisir la taille maximale d&apos;une ligne.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2263"/>
        <source>Indent statements and function parameters after wrapping.</source>
        <translation>Indenter les déclarations et les paramètres de fonctions après le retour à ligne automatique.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2266"/>
        <source>Intelligent wrapping</source>
        <translation>Retour à la ligne intelligent</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2273"/>
        <source>Do not add line numbering to lines which were automatically wrapped.</source>
        <translation>Ne pas ajouter des numéros aux retours à la ligne automatiques.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2276"/>
        <source>Omit line numbers of wrapped lines</source>
        <translation>Omettre les numéros de ligne pour les retours à la ligne</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2287"/>
        <source>Font na&amp;me:</source>
        <translation>No&amp;m de la police :</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2308"/>
        <source>Select or enter the font name. HTML supports a list of fonts, separated with comma.</source>
        <translation>Sélectionner ou saisir le nom d&apos;une police. L&apos;HTML supporte une liste de polices, séparées par des virgules.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2320"/>
        <source>Font si&amp;ze:</source>
        <translation>&amp;Taille de la police :</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2342"/>
        <source>Enter the font size.</source>
        <translation>Saisissez la taille de police.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2357"/>
        <source>&amp;Open files</source>
        <translation>&amp;Ouvrir des fichiers</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2362"/>
        <source>&amp;Exit</source>
        <translation>Quitt&amp;er</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2367"/>
        <source>&amp;Load</source>
        <translation>&amp;Charger</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2372"/>
        <source>&amp;Save</source>
        <translation>&amp;Sauvegarder</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2377"/>
        <source>Load &amp;default project</source>
        <translation>Charger le projet par &amp;défaut</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2382"/>
        <source>&amp;Readme</source>
        <translation>Lise&amp;z-moi</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2387"/>
        <source>&amp;Tips</source>
        <translation>As&amp;tuces</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2395"/>
        <source>&amp;Changelog</source>
        <translation>Journal des &amp;changements</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2400"/>
        <source>&amp;License</source>
        <translation>&amp;Licence</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2405"/>
        <source>&amp;About Highlight</source>
        <translation>&amp;À propos de Highlight</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2410"/>
        <source>A&amp;bout translations</source>
        <translation>À propos des tra&amp;ductions</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2415"/>
        <source>&amp;Visit andre-simon.de</source>
        <translation>&amp;Visiter andre-simon.de</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2426"/>
        <source>&amp;Dock floating panels</source>
        <translation>A&amp;ccrocher les panneaux flottants</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="2431"/>
        <source>&amp;Plug-Ins</source>
        <translation>&amp;Greffons</translation>
    </message>
</context>
<context>
    <name>ShowTextFile</name>
    <message>
        <location filename="showtextfile.ui" line="17"/>
        <source>Show text</source>
        <translation>Afficher le texte</translation>
    </message>
    <message>
        <location filename="showtextfile.ui" line="37"/>
        <source>TextLabel</source>
        <translation>ÉtiquetteTexte</translation>
    </message>
    <message>
        <location filename="showtextfile.ui" line="69"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>io_report</name>
    <message>
        <location filename="io_report.ui" line="14"/>
        <source>Error summary</source>
        <translation>Résumé des erreurs</translation>
    </message>
    <message>
        <location filename="io_report.ui" line="24"/>
        <source>Input errors:</source>
        <translation>Erreurs d&apos;entrée :</translation>
    </message>
    <message>
        <location filename="io_report.ui" line="34"/>
        <source>Remove files above from input file list</source>
        <translation>Supprimer ces fichiers de la liste des fichiers en entrée</translation>
    </message>
    <message>
        <location filename="io_report.ui" line="48"/>
        <source>Output errors:</source>
        <translation>Erreurs de sortie :</translation>
    </message>
    <message>
        <location filename="io_report.ui" line="65"/>
        <source>Reformatting not possible:</source>
        <translation>Reformatage impossible :</translation>
    </message>
</context>
<context>
    <name>syntax_chooser</name>
    <message>
        <location filename="syntax_chooser.ui" line="14"/>
        <source>Syntax selection</source>
        <translation>Sélection de la syntaxe</translation>
    </message>
    <message>
        <location filename="syntax_chooser.ui" line="32"/>
        <source>Select correct syntax</source>
        <translation>Sélectionner la syntaxe correcte</translation>
    </message>
    <message>
        <location filename="syntax_chooser.ui" line="50"/>
        <source>TextLabel</source>
        <translation>ÉtiquetteTexte</translation>
    </message>
    <message>
        <location filename="syntax_chooser.ui" line="74"/>
        <source>These entries are configured in filetypes.conf.</source>
        <translation>Ces entrées sont configurés dans filetypes.conf.</translation>
    </message>
    <message>
        <location filename="syntax_chooser.ui" line="81"/>
        <source>The selection will be remembered for this session.</source>
        <translation>La sélection sera mémorisée pour cette session.</translation>
    </message>
    <message>
        <location filename="syntax_chooser.ui" line="84"/>
        <source>Remember selection</source>
        <translation>Mémoriser la sélection</translation>
    </message>
    <message>
        <location filename="syntax_chooser.cpp" line="57"/>
        <source>The file extension %1 is assigned to multiple syntax definitions.
Select the correct one:</source>
        <translation>L&apos;extension de fichier %1 est assignée à plusieurs définitions de syntaxe.
Sélectionnez la bonne :</translation>
    </message>
</context>
</TS>
